
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.29.14',
    'branch_nick': 'release-1.29-LTS',
    'revision_id': 'e80c4dd3cf700383e555ce7fe45bd6c823391a75',
    'revno': 12108
}
